import { Component, OnInit, ViewChild } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import * as Parse from 'parse';
import {
  AlertController,
  IonicModule,
  LoadingController,
  ModalController,
  ToastController,
} from '@ionic/angular';
import { ActivatedRoute } from '@angular/router';
import { LiveComponent } from '../../../app/components/live/live.component';
import { LiveService } from '../../../services/live.service';
import { SharedModule } from '../../shared.module';
import { AiChatService } from '../../../services/aichart.service';
@Component({
  selector: 'app-link-page',
  templateUrl: './link-page.component.html',
  styleUrls: ['./link-page.component.scss'],
  standalone: true,
  imports: [
    IonicModule,
    FormsModule,
    LiveComponent,
    CommonModule,
    SharedModule,
  ],
})
export class LinkPageComponent implements OnInit {
  @ViewChild('live') live!: LiveComponent;
  currentUser?: Parse.Object = Parse.User.current(); //当前登录用户
  rid?: string;
  room?: Parse.Object;
  isFollow: boolean = false;
  showTool: boolean = true; // 是否显示工具栏
  showGiftModal: boolean = false; // 是否显示礼物弹窗
  giftList: Array<any> = [];
  tabs: Array<any> = [
    {
      name: '礼物',
      val: 'all',
    },
    {
      name: '专属礼物',
      val: 'vip',
    },
    {
      name: '守护',
      val: 'guard',
    },
  ];
  activeTab: string = 'all';
  currentGift: any; //当前礼物
  giftCount: number = 1;
  wallet: any = { balance: 0 };
  isShowGiftModal: boolean = false; // 是否显示礼物动效弹窗
  times: any;
  constructor(
    public toastController: ToastController,
    private loadingCtrl: LoadingController,
    private alertController: AlertController,
    private activateRoute: ActivatedRoute,
    private aiServ: AiChatService,
    public liveService: LiveService
  ) {}

  ngOnInit() {
    this.activateRoute.paramMap.subscribe(async (params) => {
      let rid: any = params.get('rid');
      this.rid = rid;
      if (!this.rid) {
        history.back();
        return;
      }
      this.refresh();
    });
  }
  async refresh() {
    const loading = await this.loadingCtrl.create({
      message: '加载中',
    });
    loading.present();
    this.getRoom();
    this.giftList = await this.aiServ.getGift();
    console.log(this.giftList);
    loading.dismiss();
  }
  async getRoom() {
    let query = new Parse.Query('Room');
    query.equalTo('objectId', this.rid);
    query.notEqualTo('isDeleted', true);
    query.include('user');
    query.select('user');
    this.room = await query.first();
    this.getFollwState(this.room?.get('user').id);
  }
  /* 关注状态 */
  async getFollwState(uid: string) {
    let query = new Parse.Query('ProfileRadar');
    query.equalTo('toUser', uid);
    query.equalTo('fromUser', this.currentUser?.id);
    query.notEqualTo('isDeleted', true);
    query.equalTo('name', '关注');
    let r = await query.first();
    this.isFollow = r?.id ? true : false;
  }
  async selectTab(val: string) {
    if (this.activeTab === val) return;
    this.giftList = await this.aiServ.getGift(val == 'all' ? '' : val);
    this.activeTab = val;
    this.currentGift = null;
  }
  /* 关注 */
  async onCollection() {
    let query = new Parse.Query('ProfileRadar');
    query.equalTo('toUser', this.room?.get('user').id);
    query.equalTo('fromUser', this.currentUser?.id);
    // query.notEqualTo('isDeleted', true);
    query.equalTo('name', '关注');
    let profileRadar = await query.first();
    if (!profileRadar?.id) {
      let radar = Parse.Object.extend('ProfileRadar');
      profileRadar = new radar();
      profileRadar?.set('toUser', {
        __type: 'Pointer',
        className: '_User',
        objectId: this.room?.get('user').id,
      });
      profileRadar?.set('company', {
        __type: 'Pointer',
        className: 'Company',
        objectId: this.currentUser?.get('company')?.id,
      });
      profileRadar?.set('fromUser', this.currentUser?.toPointer());
      profileRadar?.set('name', '关注');
    }
    profileRadar?.set('isDeleted', this.isFollow);
    await profileRadar?.save();
    this.isFollow = !this.isFollow;
  }
  /* 直播状态 */
  async onChangeLiveStatus(e: any, type: string) {
    e.cancelBubble = true;
    switch (type) {
      case 'audio':
        this.liveService.updatePublishedAudioTrack();
        break;
      case 'camera':
        this.liveService.changeCamera();
        break;
      case 'mute':
        this.liveService.muteAudio();
        break;
      case 'gift':
        let uid: any = Parse.User.current()?.id;
        this.wallet = await this.aiServ.getWallet(uid);
        this.showGiftModal = true;
        break;
    }
  }
  async sendGift() {
    if (!this.currentGift?.id || this.giftCount < 1) return;
    const alert = await this.alertController.create({
      cssClass: 'my-custom-class',
      header: '送出礼物',
      message: `确定送出${this.giftCount}件${this.currentGift.name}吗`,
      buttons: [
        {
          text: '取消',
          role: 'cancel',
          cssClass: 'secondary',
          handler: (blah) => {},
        },
        {
          text: '确定',
          handler: async () => {
            const loading = await this.loadingCtrl.create({
              message: '送出礼物中...',
            });
            loading.present();
            let fid = this.room?.get('user').id;
            this.aiServ
              .putGift(fid, this.currentGift.id, this.giftCount)
              .then((data) => {
                console.log(data);
                this.liveService.get_duration()
                loading.dismiss();
                this.showGiftModal = false;
                this.isShowGiftModal = true;
                setTimeout(() => {
                  this.isShowGiftModal = false;
                }, 5000);
              })
              .catch((err) => {
                this.showGiftModal = false;
                loading.dismiss();
                console.error(err);
              });
          },
        },
      ],
    });
    await alert.present();
  }

  onChange() {
    this.giftCount = this.giftCount < 1 ? 1 : Math.floor(this.giftCount);
    console.log(this.giftCount);
  }
  /* 结束直播 */
  async endCall(e: any) {
    e.cancelBubble = true;
    const alert = await this.alertController.create({
      cssClass: 'my-custom-class',
      header: '退出提示',
      message: '你确定退出登录吗？',
      buttons: [
        {
          text: '取消',
          role: 'cancel',
          handler: (blah) => {
          },
        },
        {
          text: '确定',
          cssClass: 'secondary',
          handler: () => {
            console.log('Confirm Cancel: blah');
            this.onExit();
          },
        },
      ],
    });
    await alert.present();
  }
  async onReport(e: any){
    e.cancelBubble = true;
    const alert = await this.alertController.create({
      cssClass: 'my-custom-class',
      header: '举报',
      message: '请填写您需要举报的内容',
      inputs: [
        {
          name: 'report',
          type: 'textarea',
          placeholder: '举报内容',
        },
      ],
      buttons: [
        {
          text: '取消',
          role: 'cancel',
          handler: (data) => {},
        },
        {
          text: '确定',
          cssClass: 'secondary',
          handler: (data) => {
            let report = data.report;
            console.log(report);
          },
        },
      ],
    });
    await alert.present();
  }
  onExit() {
    this.liveService.client.leave();
    history.back();
  }
}
